aboutsummaryrefslogtreecommitdiff
path: root/lib/easy.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/easy.c')
-rw-r--r--lib/easy.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/easy.c b/lib/easy.c
index ce83238d6..5ecd10575 100644
--- a/lib/easy.c
+++ b/lib/easy.c
@@ -211,7 +211,7 @@ CURLcode curl_easy_setopt(CURL *curl, CURLoption tag, ...)
func_T param_func = (func_T)0;
long param_long = 0;
void *param_obj = NULL;
- off_t param_offset = 0;
+ curl_off_t param_offset = 0;
struct SessionHandle *data = curl;
CURLcode ret=CURLE_FAILED_INIT;
@@ -239,8 +239,8 @@ CURLcode curl_easy_setopt(CURL *curl, CURLoption tag, ...)
param_func = va_arg(arg, func_T );
ret = Curl_setopt(data, tag, param_func);
} else {
- /* This is an off_t type */
- param_offset = va_arg(arg, off_t);
+ /* This is a curl_off_t type */
+ param_offset = va_arg(arg, curl_off_t);
ret = Curl_setopt(data, tag, param_offset);
}